pub enum P2shItemKind {
FullViewing,
IncomingViewing,
}Expand description
The kinds of unified viewing key container in which a P2SH viewing key item can occur, determining the multipath notation its descriptor template must use.
Variants
FullViewing
An item in a Unified Full Viewing Key, whose descriptor template must use the
/** multipath notation for each key placeholder.
IncomingViewing
An item in a Unified Incoming Viewing Key, whose descriptor template must use the
/* notation for each key placeholder.