pub enum ParseError {
Show 13 variants
BothP2phkAndP2sh,
DuplicateTypecode(Typecode),
InvalidTypecodeValue(u64),
InvalidEncoding(String),
InvalidTypecodeOrder,
OnlyTransparent,
NotUnified,
UnknownPrefix(String),
NotUnderstood(u32),
TransparentReceiverInR2Address,
NoDataItems,
InvalidMetadataLength {
typecode: u32,
expected: usize,
actual: usize,
},
InvalidP2shItem(P2shItemError),
}Expand description
An error while attempting to parse a string as a Zcash address.
Variants
BothP2phkAndP2sh
The unified container contains both P2PKH and P2SH items.
DuplicateTypecode(Typecode)
The unified container contains a duplicated typecode.
InvalidTypecodeValue(u64)
The parsed typecode exceeds the maximum allowed CompactSize value.
InvalidEncoding(String)
The string is an invalid encoding.
InvalidTypecodeOrder
The items in the unified container are not in typecode order.
OnlyTransparent
The unified container only contains transparent items.
NotUnified
The string is not Bech32m encoded, and so cannot be a unified address.
UnknownPrefix(String)
The Bech32m string has an unrecognized human-readable prefix.
NotUnderstood(u32)
A MUST-understand metadata typecode was encountered that this implementation does not recognize.
TransparentReceiverInR2Address
A transparent receiver was found in a Revision 2 Unified Address.
NoDataItems
The unified container has no data items.
InvalidMetadataLength
A metadata item has an invalid length.
InvalidP2shItem(P2shItemError)
A P2SH viewing key item is structurally invalid.